import pandas as pd
import matplotlib.pyplot as plt
import numpy as np

#Chargement des données du fichier csv :
att=pd.read_csv("beton.csv", delimiter=';')
Ebeton=att["E(MeV)"]*1000#conversion en keV
mu=att["mu/rho"]#coeff. massique d'atténuation
#---------------------------------------------------------------------------------------
x=np.arange(0, 11.1, 0.1)#épaisseur traversée (en mm)

#Réglages du graphique :
fig=plt.figure(figsize=(7, 9))
ax=plt.subplot(111)
ax.set_yscale("log")

plt.ylim(1e-4, 2)
plt.title("Atténuation de rayons X dans le béton", fontsize=14)
plt.xlabel("épaisseur de matériau traversé (mm)")
plt.ylabel("facteur d'atténuation")
xmax=0.4#mm
plt.xlim(0, xmax)
ax.xaxis.set_ticks(np.arange(0, xmax, 0.1))#espacement graduations x
ax.xaxis.set_ticks(np.arange(0, xmax, 0.01), minor=True)#grille 2daire x
plt.grid(which='both')
ax.grid(which='minor', alpha=0.5)#grille 2daire estompée

#Tracé des courbes :

Energies=[1, 2, 3, 4, 5]#À choisir par l'utilisateur (en keV)
"""
Si des valeurs de la liste Energies ne figurent pas dans le
fichier csv, elles ne seront pas prises en compte.
"""

def test(e):#teste si la valeur d'énergie e est dans la liste E
    resultat=False
    for E in Ebeton:
        if E==e:
            resultat=True
    return resultat
    
for energie in Energies:
    if test(energie):
        mu=float(att.loc[Ebeton==energie, "mu/rho"])
        attenuation=np.exp(-mu*x/10)#Le "/10" convertit x en cm
        plt.plot(x, attenuation, label="E=%s keV"%(energie))

plt.legend()
fig.savefig("FacteurAttenuationBetondpi400.png", dpi=400)
plt.show()
